# IRP

## About this template

We generated this repository for you to work in during your IRP. Please note that if your code is confidential, you do not need to submit your code here.

- For project information updates, please refer to `README.md` in [`info/`](./info) directory.
- For details on deliverable submissions, please refer to `README.md` in [`reports/`](./reports) directory.

If you have any questions or experience any difficulties, please do not hesitate to get in touch with Marijan (m.beg@imperial.ac.uk).

Please feel free to remove this text from `README.md` and write it the way you want. ;)
